==> Smdn.Net.Pop3.Client-0.22.tar.bz2: Smdn.Net.Pop3.Client-0.22/Smdn.Net.Pop3.Client/Smdn.Net.Pop3.Client.Session/PopIncapableException.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;

namespace Smdn.Net.Pop3.Client.Session {
  // Exceptions:
  //   System.Excpetion
  //     System.SystemException
  //       Smdn.Net.Pop3.PopExcetion
  //         Smdn.Net.Pop3.Client.Session.PopIncapableException

  public class PopIncapableException : PopException {
    public PopCapability RequiredCapability {
      get; private set;
    }

    public PopIncapableException(PopCapability requiredCapability)
      : this(string.Format("{0} is incapable", requiredCapability), requiredCapability)
    {
    }

    public PopIncapableException(string message, PopCapability requiredCapability)
      : base(message)
    {
      RequiredCapability = requiredCapability;
    }

    public PopIncapableException(string message)
      : base(message)
    {
    }
  }
}

==> Smdn.Net.Pop3.Client-0.28.tar.bz2: Smdn.Net.Pop3.Client-0.28/Smdn.Net.Pop3.Client/Smdn.Net.Pop3.Client.Session/PopIncapableException.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;

namespace Smdn.Net.Pop3.Client.Session {
  // Exceptions:
  //   System.Excpetion
  //     System.SystemException
  //       Smdn.Net.Pop3.PopExcetion
  //         Smdn.Net.Pop3.Client.Session.PopInvalidOperationException
  //           Smdn.Net.Pop3.Client.Session.PopIncapableException

  public class PopIncapableException : PopInvalidOperationException {
    public PopCapability RequiredCapability {
      get; private set;
    }

    public PopIncapableException(PopCapability requiredCapability)
      : this(string.Format("{0} is incapable", requiredCapability), requiredCapability)
    {
    }

    public PopIncapableException(string message, PopCapability requiredCapability)
      : base(message)
    {
      RequiredCapability = requiredCapability;
    }

    public PopIncapableException(string message)
      : base(message)
    {
    }
  }
}
